mix.loglik: Compute the log likelihood of input data given a parameter vector and a list of 2 distribution functions.
Description
This is the main function to compute the likelihood... ??This function is not intended to be called directly by users, but can be useful to test user-specified distributions passed to mix.mle.
Usage
mix.loglik(.pars, .input, .distlist, do.sum = TRUE)
Arguments
.pars
A list of 5 the following 5 parameters:
Probability of second distribution.
- dist1.par1
Lower distribution: mean for normal, shape for gamma
- dist1.par2
Lower distribution: SD Value
- Numeric: the negative log likelihod of ??